[SCM] Samba Shared Repository - branch master updated

Jeremy Allison jra at samba.org
Tue Aug 30 07:22:03 UTC 2016


The branch, master has been updated
       via  dd5439e tests/samba-tool/user.py: replace deprecated 'add' subcommand with 'create'
       via  58889e0 s3/rpc_server: shared rpc modules directory may not exist
      from  9395d95 pthreadpool: Signal job completion without the pool mutex

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit dd5439e8c859f3a4420bdcf79f2199e597de028c
Author: Rowland Penny <rpenny at samba.org>
Date:   Sun Aug 28 09:29:33 2016 +0100

    tests/samba-tool/user.py: replace deprecated 'add' subcommand with 'create'
    
    Signed-off-by: Rowland Penny <rpenny at samba.org>
    Reviewed-by: Jeremy Allison <jra at samba.org>
    
    Autobuild-User(master): Jeremy Allison <jra at samba.org>
    Autobuild-Date(master): Tue Aug 30 09:21:09 CEST 2016 on sn-devel-144

commit 58889e04bd545d7420d1193e134351bd0ccb8430
Author: Ralph Boehme <slow at samba.org>
Date:   Sat Aug 27 17:56:56 2016 +0200

    s3/rpc_server: shared rpc modules directory may not exist
    
    A shared rpc modules directory may not exist if all RPC modules are built
    static.
    
    Bug: https://bugzilla.samba.org/show_bug.cgi?id=12184
    
    Signed-off-by: Ralph Boehme <slow at samba.org>
    Reviewed-by: Jeremy Allison <jra at samba.org>

-----------------------------------------------------------------------

Summary of changes:
 python/samba/tests/samba_tool/user.py  | 10 +++++-----
 source3/rpc_server/rpc_service_setup.c | 12 +++++++++++-
 2 files changed, 16 insertions(+), 6 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/rpc_server/rpc_service_setup.c b/source3/rpc_server/rpc_service_setup.c
index e1625ee..263fcaf 100644
--- a/source3/rpc_server/rpc_service_setup.c
+++ b/source3/rpc_server/rpc_service_setup.c
@@ -536,7 +536,17 @@ bool dcesrv_ep_setup(struct tevent_context *ev_ctx,
 	/* Initialize shared modules */
 	mod_init_fns = load_samba_modules(tmp_ctx, "rpc");
 	if (mod_init_fns == NULL) {
-		DBG_ERR("Loading shared RPC modules failed\n");
+		if (errno != ENOENT) {
+			/*
+			 * ENOENT means the directory doesn't exist
+			 * which can happen if all modules are
+			 * static. So ENOENT is ok, everything else is
+			 * not ok.
+			 */
+			DBG_ERR("Loading shared RPC modules failed [%s]\n",
+				strerror(errno));
+			ok = false;
+		}
 		goto done;
 	}
 


diff --git a/python/samba/tests/samba_tool/user.py b/python/samba/tests/samba_tool/user.py
index d2eb0e6..10e4f6c 100644
--- a/python/samba/tests/samba_tool/user.py
+++ b/python/samba/tests/samba_tool/user.py
@@ -82,7 +82,7 @@ class UserCmdTestCase(SambaToolCmdTest):
 
         # test adding users with --use-username-as-cn
         for user in self.users:
-            (result, out, err) =  self.runsubcmd("user", "add", user["name"], user["password"],
+            (result, out, err) =  self.runsubcmd("user", "create", user["name"], user["password"],
                                                  "--use-username-as-cn",
                                                  "--surname=%s" % user["surname"],
                                                  "--given-name=%s" % user["given-name"],
@@ -382,7 +382,7 @@ class UserCmdTestCase(SambaToolCmdTest):
             return
 
 
 # samba-tool user add command didn't support users with empty gecos if none is
 # specified on the command line and the user hasn't one in the passwd file it
 # will fail, so let's add some contents
 
@@ -398,7 +398,7 @@ class UserCmdTestCase(SambaToolCmdTest):
                         "loginShell": u[6],
                         })
         # check if --rfc2307-from-nss sets the same values as we got from pwd.getpwuid()
-        (result, out, err) = self.runsubcmd("user", "add", user["name"], user["password"],
+        (result, out, err) = self.runsubcmd("user", "create", user["name"], user["password"],
                                                 "--surname=%s" % user["surname"],
                                                 "--given-name=%s" % user["given-name"],
                                                 "--job-title=%s" % user["job-title"],
@@ -423,7 +423,7 @@ class UserCmdTestCase(SambaToolCmdTest):
         user = self._randomPosixUser({"name": u[0]})
         # create a user with posix attributes from nss but override all of them with the
         # random ones just obtained
-        (result, out, err) = self.runsubcmd("user", "add", user["name"], user["password"],
+        (result, out, err) = self.runsubcmd("user", "create", user["name"], user["password"],
                                                 "--surname=%s" % user["surname"],
                                                 "--given-name=%s" % user["given-name"],
                                                 "--job-title=%s" % user["job-title"],
@@ -503,7 +503,7 @@ class UserCmdTestCase(SambaToolCmdTest):
         self._check_user(user)
 
     def _create_user(self, user):
-        return self.runsubcmd("user", "add", user["name"], user["password"],
+        return self.runsubcmd("user", "create", user["name"], user["password"],
                                                 "--surname=%s" % user["surname"],
                                                 "--given-name=%s" % user["given-name"],
                                                 "--job-title=%s" % user["job-title"],
@@ -382,7 +382,7 @@ class UserCmdTestCase(SambaToolCmdTest):
 
 
-# samba-tool user add command didn't support users with empty gecos if none is
+# samba-tool user create command didn't support users with empty gecos if none is
 # specified on the command line and the user hasn't one in the passwd file it
 # will fail, so let's add some contents
-- 
Samba Shared Repository



More information about the samba-cvs mailing list